"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = _default;

var _pluginOption = _interopRequireDefault(require("./utils/pluginOption"));

var _tools = require("./utils/tools");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _default({
  types: t
}) {
  const visitor = {
    CallExpression(path) {
      if (t.isMemberExpression(path.node.callee) && path.node.callee.object.name === 'console') {
        // options need to be an object
        if (this.opts && !(0, _tools.isObject)(this.opts)) {
          return console.error('[babel-plugin-console-enhanced]: options need to be an object.');
        }

        const options = (0, _pluginOption.default)(this.opts);
        const filename = this.filename || this.file.opts.filename || 'unknown'; // not work on an excluded file

        if (Array.isArray(options.exclude) && options.exclude.length && (0, _tools.matchesExclude)(options.exclude, filename)) {
          return;
        } // not work on a non-inlcuded method


        if (!options.methods.includes(path.node.callee.property.name)) {
          return;
        }

        let description = '';

        if (options.addFilename) {
          description = `${description}filename: ${filename}, `;
        }

        if (options.addCodeLine) {
          const line = path.node.loc.start.line;
          description = `${description}line: ${line}, `;
        }

        if (options.addCodeColumn) {
          const column = path.node.loc.start.column;
          description = `${description}column: ${column}, `;
        }

        if (options.addContext) {
          const scope = (0, _tools.computeContext)(path);
          description = scope ? `${description}context: ${scope}, ` : description;
        }

        if (options.customContent) {
          description = `${description}${options.customContent}, `;
        }

        if (description) {
          path.node.arguments.unshift(t.stringLiteral(description));
        }
      }
    }

  };
  return {
    name: 'babel-plugin-console-enhanced',
    visitor
  };
}